--shadertoy code implement
--modify shaderFileName to the code file you copied.
--if the shader has any channel file, for example channel0 then shaderChannel[1]=love.graphics.newImage(path to the file)
local resolution={800,600,1} --low resolution for better performance

local shaderFileName="shader/raycast2d.glsl"
local shaderChannel={
  --[0]=love.graphics.newImage("channel/tex11.png"),
  --[1]=love.graphics.newImage("channel/tex15.png"),
  --[3]=love.graphics.newImage("channel/tex15.png"),
}

local function loadShader(path)
    local iSystem={}
    local header="\n"
    local ender=[[vec4 effect(vec4 color, Image texture, vec2 texture_coords, vec2 pixel_coords){
    vec2 fragCoord = texture_coords * iResolution.xy;
    mainImage( color, fragCoord );
    return color;
}]]
    local file = love.filesystem.newFile(path)
    file:open("r")
    local shaderData = file:read()
    string.gsub(shaderData,"texture2D","Texel")
    if string.find(shaderData,"iGlobalTime") then
      iSystem.iGlobalTime=0
      header="\nextern number iGlobalTime;"..header
    end
    if string.find(shaderData,"iChannel") then
      iSystem.iChannel={}
      for k,v in pairs(shaderChannel) do
        header="\nextern Image iChannel"..k..";"..header
      end
    end
    if string.find(shaderData,"iMouse") then
      iSystem.iMouse = {0,0,-1,-1}
      header="\nextern vec4 iMouse;"..header
    end
    if string.find(shaderData,"iResolution") then
      iSystem.iResolution = {resolution[1],resolution[2],1}
      header="\nextern vec3 iResolution;"..header
    end        
    shaderData=header..shaderData..ender
    return shaderData,iSystem
end

local shaderData,iSystem = loadShader(shaderFileName)
local shader = love.graphics.newShader(shaderData)
local canvas = love.graphics.newCanvas(resolution[1],resolution[2])

if iSystem.iResolution then
  shader:send("iResolution",iSystem.iResolution)
end
if iSystem.iChannel then
  for k,v in pairs(shaderChannel) do
    shader:send("iChannel"..k,v)
  end
end

function love.update(dt)
  if iSystem.iGlobalTime then
    iSystem.iGlobalTime=iSystem.iGlobalTime+dt
    shader:send("iGlobalTime", iSystem.iGlobalTime)
  end
  if iSystem.iMouse then
    iSystem.iMouse[1],iSystem.iMouse[2] = love.mouse.getPosition()
    if love.mouse.isDown("l") then
        if iSystem.iMouse[3]<0 then
          iSystem.iMouse[3],iSystem.iMouse[4] = love.mouse.getPosition()
        end
        shader:send("iMouse", iSystem.iMouse)
    else
        iSystem.iMouse[3],iSystem.iMouse[4] = -1, -1
    end
  end
  love.window.setTitle(shaderFileName.."; FPS: "..love.timer.getFPS())
  love.graphics.setCanvas(canvas)
    love.graphics.setShader(shader)
    love.graphics.draw(canvas)
    love.graphics.setShader()
  love.graphics.setCanvas()
end

function love.draw()
  love.graphics.draw(canvas,0,0,0,-800/resolution[1],-600/resolution[2],resolution[1],resolution[2])
end